"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RULE_NAME = void 0;
const bundled_angular_compiler_1 = require("@angular-eslint/bundled-angular-compiler");
const utils_1 = require("@angular-eslint/utils");
const create_eslint_rule_1 = require("../utils/create-eslint-rule");
exports.RULE_NAME = 'i18n-not-allowed';
let x = false;
exports.default = (0, create_eslint_rule_1.createESLintRule)({
    name: exports.RULE_NAME,
    meta: {
        type: 'suggestion',
        docs: {
            description: 'Make sure no use of i18n',
        },
        fixable: 'code',
        hasSuggestions: true,
        schema: [
            {
                type: 'object',
                properties: {},
                additionalProperties: false,
            },
        ],
        messages: {
            i18nIsNotAllowed: `i18n tag is not allowed`,
        },
    },
    defaultOptions: [],
    create(context) {
        const parserServices = (0, utils_1.getTemplateParserServices)(context);
        function handleElementOrTemplate(node) {
            const { i18n, sourceSpan, parent } = node;

            if (!i18n) {
                return;
            }

            if (isElementWithI18n(parent) || isTemplateWithI18n(parent)) {
                return;
            }

            const loc = parserServices.convertNodeSourceSpanToLoc(sourceSpan);
            context.report({
                messageId: 'i18nIsNotAllowed',
                loc,
            });
        }
        return {
            ':matches(Element$1, Template[tagName="ng-template"])[i18n]'(node) {
                handleElementOrTemplate(node);
            },
        };
    },
});
function isElement(ast) {
    return ast instanceof bundled_angular_compiler_1.TmplAstElement;
}
function isElementWithI18n(ast) {
    return Boolean(isElement(ast) && ast.i18n);
}
function isTemplate(ast) {
    return ast instanceof bundled_angular_compiler_1.TmplAstTemplate;
}
function isTemplateWithI18n(ast) {
    return Boolean(isTemplate(ast) && ast.i18n);
}
